
  
##### Import packages  
install.packages("cmdstanr")
install.packages("dplyr")
library(cmdstanr)
library(dplyr)
library(ggplot2)
library(tidyverse)
library(brms)
library(tidybayes)
library(lubridate)
library(ggcorrplot)

# packages
library(pander)
library(kableExtra)
library(emmeans)
library(here)
library(broom)          
library(extraDistr)       
library(ggdist)           
library(gghalves)        
library(patchwork) 
check_cmdstan_toolchain(fix = TRUE, quiet = TRUE)

#####1. Import data

  
data <- read_csv("G:/.shortcut-targets-by-id/15aIOTzK-SdA0QZzPxWaQk_8cNO0OoEUl/Rebekah thesis/R/FINAL clean provisioning data 2013-2019.csv")

  
#####2. Calculate nestling age 

#Create julian date which starts at 1 for 1st hatch date for full dataset (2013-2019)
  
summary(data$julian2)
data$jhatchdate <- data$julian2-186

#Create julian for date in season for full dataset (2013-2019)#
  
summary(data$jdate2)
data$dayinseason <- data$jdate2-186 #-186 not 187 to align with hatchdate

#Calculate nestling age#
  
data$nestlingage <- data$dayinseason - data$jhatchdate
hist(data$nestlingage) #check distribution (confirm logical)
summary(data$nestlingage) #no problems 

#####4. Set appropriate categorical variables 

  
data$fpair <- as.factor(data$yearsite)
data$fsite <- as.factor(data$site)
data$fyear <- as.factor(data$year)


#####5. Calculate IVI 


  #Combine provisioning start date & time#
  
data$DTstart <- as.POSIXct(as.character(paste(data$date, data$start)), 
                           format = "%d/%m/%Y %H:%M:%S")

#Calculate IVI#
  
data1 <- (data=data) %>% 
  group_by (fpair) %>% 
  arrange(DTstart) %>% 
  mutate(IVI = ifelse(visit_type == "fail"| lag(visit_type == "fail"), NA, DTstart - lag(DTstart, default = first(DTstart)))) %>% 
  ungroup()

data1$IVI <- data1$IVI/60


#####6. Limit dataset to first 12 days 

  #We did this since nestlings begin to move out of the range of the cameras from 13 days post hatch, thus we can no longer reliably score provisioning visits after day 12. 

 # We also excluded the hatch day (day 0) as there would be great variability in number of provisioning visits to a nestling which hatched at 9am vs. 9pm, for example. 


data1 <- (data=data1) %>%
  filter(data$nestlingage <=12) 
data1 <- (data=data1) %>%
  filter(data$nestlingage >0)


#####7. Deal with camera fail lines 


#We removed NAs since these are generated by fails recorded either on the current or previous line


data1 <- (data=data1) %>% 
  filter(!is.na (IVI))
summary(data1$IVI)


#####8. Check for outliers in IVI

dotchart(data1$IVI) # outliers seem obvious, remove obvious outliers 
# Longest IVI is 9296 minutes (6.5 days) which is obviously unrealistic. It is from 2015. 
# The 7 longest IVIs are from 2015 and 2016
# 8th longest is from 2019 and is 2671 (1.9 days)

data1 <- (data=data1) %>%
  filter(data1$IVI <4000)
dotchart(data1$IVI)

#####9. Log transform IVI

hist(data1$IVI)
data1$logIVI <- log(data1$IVI)
hist(data1$logIVI)

#####10. Manipulate fixed effects 

  #left 0 brood size and nestling age#
  #This is to allow for biologically meaningful interpretation of results 

data1$nestlingagel <- data1$nestlingage-1
data1$chicksl <- data1$chicks-1


#scale and center brood size#
  
data1$cschicksl <- scale(data1$chicksl)# center by default 

#scale nestling age#

#data1$snestlingagel <- scale(data1$nestlingagel, center = FALSE)
# need to change as it seems to be scaled by 2*SD  

# changed to this (manual scaling)
data1$snestlingagel <- data1$nestlingagel/sd(data1$nestlingagel)
  
#####11. Remove supplemented nests 

data1 <- (data=data1) %>%
  filter(data$supplemented == "n")

##### 12. Models & associated figures 

mod1<- brm(bf(logIVI ~ 1 + cschicksl + snestlingagel +  
              (1 |p|fyear) + (1 | fsite) + (1|fpair), 
            sigma ~ 1 + cschicksl+ snestlingagel+ (1|p|fyear)), 
             data = data1, 
             warmup = 1000, 
             iter = 5000, 
             chains = 2,
             cores  = 2,
             control = list(adapt_delta = 0.99, max_treedepth = 15),
             backend = "cmdstanr")
summary(mod1)
ranef(mod1)
fixef(mod1)


saveRDS(mod1, file = "Rebekah_Kim/mod1.rds")

# not to run
#mod1 <- readRDS(file = "mod1.rds")


# mod2 
mod2<- brm(bf(logIVI ~ 1 + cschicksl + snestlingagel +  
                (1 + snestlingagel |p|fyear) + (1 | fsite) + (1|fpair), 
              sigma ~ 1 + cschicksl+ snestlingagel+ (1|p|fyear)), 
           data = data1, 
           warmup = 1000, 
           iter = 5000, 
           chains = 2,
           cores  = 2,
           control = list(adapt_delta = 0.99, max_treedepth = 15),
           backend = "cmdstanr")


summary(mod2)
ranef(mod2)
fixef(mod2)


saveRDS(mod2, file = "Rebekah_Kim/mod2.rds")

# not to run
#mod2 <- readRDS(file = "mod2.rds")

# mod 3
mod3<- brm(bf(logIVI ~ 1 + cschicksl + snestlingagel +  
                (1 + cschicksl + snestlingagel |p|fyear) + (1 | fsite) + (1|fpair), 
              sigma ~ 1 + cschicksl+ snestlingagel+ (1|p|fyear)), 
           data = data1, 
           warmup = 1000, 
           iter = 5000, 
           chains = 2,
           cores  = 2,
           control = list(adapt_delta = 0.99, max_treedepth = 15),
           backend = "cmdstanr")


summary(mod3)
ranef(mod3)
fixef(mod3)


saveRDS(mod3, file = "Rebekah_Kim/mod3.rds")

# not to run
#mod3 <- readRDS(file = "mod3.rds")

# comparing

loo_mod1 <- loo(mod1)
loo_mod2 <- loo(mod2)
loo_mod3 <- loo(mod3)

loo_compare(loo_mod1, loo_mod2, loo_mod3)

# draw figs for mod2

# wrting functions

mod2 %>% 
  emmeans(~ snestlingagel,
          at = list(snestlingagel = seq(min(data1$snestlingagel),
                                        max(data1$snestlingagel),length.out = 100)),
          epred = TRUE,
          re_formula = NA) %>% as_tibble()  %>% 
  mutate(nestlingagel = snestlingagel*attr(data1$snestlingagel,"scaled:scale")
         ) -> 
  predications_nest

mod2 %>% 
  emmeans(~ cschicksl,
          at = list(cschicksl = seq(min(data1$cschicksl),
                                        max(data1$cschicksl),length.out = 100)),
          epred = TRUE,
          re_formula = NA) %>% as_tibble()  %>% 
  mutate(chicksl = cschicksl*attr(data1$cschicksl,"scaled:scale") + attr(data1$cschicksl,"scaled:center") 
         ) -> 
  predications_chick

# data1$cschicksl <- scale(data1$cschicksl)#

# creating posteriors
new_mat_nest <- expand_grid(
  snestlingagel = seq(min(data1$snestlingagel),
                     max(data1$snestlingagel),length.out = 100),
  cschicksl = mean(data1$cschicksl))

new_mat_chick <- expand_grid(
  snestlingagel = mean(data1$snestlingagel),
  cschicksl = seq(min(data1$cschicksl),
                    max(data1$cschicksl),length.out = 100))


posterior_nest <- epred_draws(mod2, newdata = new_mat_nest,
                              dpar = c("mu", "sigma"), 
                              re_formula = NA
) %>% 
  group_by(snestlingagel, .draw) %>% summarise(snestlingagel = mean(snestlingagel),
                                       predicted = mean(.epred),
                                       mu = mean(mu),
                                       sigma = mean(sigma),
                                       nestlingagel = 
                                         snestlingagel*(attr(data1$snestlingagel,"scaled:scale")) 
                                       )

posterior_chick <- epred_draws(mod2, newdata = new_mat_chick,
                               dpar = c("mu", "sigma"), 
                               re_formula = NA
) %>% 
  group_by(cschicksl, .draw) %>% 
           summarise(cschicksl = mean(cschicksl),
           predicted = mean(.epred),
           mu = mean(mu),
           sigma = mean(sigma),
           chicksl = cschicksl*(attr(data1$cschicksl,"scaled:scale")) + attr(data1$cschicksl,"scaled:center")
  )

# mean model

# nest 
mean_nest <- ggplot()+
  # confidence interval
  geom_smooth(data = predications_nest, aes(x = nestlingagel, y = lower.HPD), method =  "loess", formula = y~x, se = FALSE, lty =  "dotted", lwd = 1,  col = "black") +
  geom_smooth(data = predications_nest, aes(x = nestlingagel, y = upper.HPD), method =  "loess", formula = y~x, se = FALSE, lty = "dotted", lwd = 1,  col = "black") +
  # main line
  geom_smooth(data = predications_nest, aes(x = nestlingagel, y = emmean), method =  "loess", formula = y~x, se = FALSE, lwd = 1.5, col = "black") +
  # real data
  geom_jitter(data = data1, aes(x = nestlingagel, y = logIVI, fill = fpair, color = fpair), shape = 21, alpha = 0.5, width = 0.2) +
  geom_smooth(data = data1,  aes(x = nestlingagel, y = logIVI, color = fpair), method = "lm", formula = y ~x, se = FALSE, lwd = 0.1) + 
  scale_fill_viridis_d(end = 0.8) +
  scale_colour_viridis_d(end = 0.8) +
  labs(y = "log(IVI)", x =  "Nestling age (days)") +
  # themes
  theme_bw(base_size = 12) +  theme(legend.position = "none")

mean_nest

# chick 
mean_chick <- ggplot()+
  # confidence interval
  geom_smooth(data = predications_chick, aes(x = chicksl, y = lower.HPD), method =  "loess", formula = y~x, se = FALSE, lty =  "dotted", lwd = 1,  col = "black") +
  geom_smooth(data = predications_chick, aes(x = chicksl, y = upper.HPD), method =  "loess", formula = y~x, se = FALSE, lty = "dotted", lwd = 1,  col = "black") +
  # main line
  geom_smooth(data = predications_chick, aes(x = chicksl, y = emmean), method =  "loess", formula = y~x, se = FALSE, lwd = 1.5, col = "black") +
  # real data
  geom_jitter(data = data1, aes(x = chicksl, y = logIVI, fill = fpair, color = fpair), shape = 21, alpha = 0.5, width = 0.3) +
  geom_smooth(data = data1,  aes(x = chicksl, y = logIVI, color = fpair), method = "lm", formula = y ~x, se = FALSE, lwd = 0.1) + 
  scale_fill_viridis_d(end = 0.8) +
  scale_colour_viridis_d(end = 0.8) +
  labs(y = "log(IVI)", x ="Brood Size") +
  # themes
  theme_bw(base_size = 12) +  theme(legend.position = "none")

mean_chick


# SD model

sd_nest <- ggplot(posterior_nest, aes(x = nestlingagel, y = sigma)) +
  stat_lineribbon(aes(fill_ramp = stat(level))) +
  scale_fill_viridis_d(option = "viridis", end = 0.8) +
  scale_color_viridis_d(option = "viridis", end = 0.8) +
  scale_fill_ramp_discrete(range = c(0.5, 0.8)) +
  ylim(0.75, 1.25) +
  labs(y = "sigma_log(IVI)", x = "Nestling age (days)",
       fill_ramp = "Credible interval") +
  guides(fill = "none", color = "none") +
  theme_bw(base_size = 12) +
  #theme(legend.position = "none")
  theme(legend.position = "bottom", text = element_text(size = 10))

sd_nest
  

sd_chick <- ggplot(posterior_chick, aes(x = chicksl, y = sigma)) +
  stat_lineribbon(aes(fill_ramp = stat(level))) +
  scale_fill_viridis_d(option = "viridis", end = 0.8) +
  scale_color_viridis_d(option = "viridis", end = 0.8) +
  scale_fill_ramp_discrete(range = c(0.5, 0.8)) +
  ylim(0.75, 1.25) +
  labs(y = "sigma_log(IVI)", x = "Brood Size",
       fill_ramp = "Credible interval") +
  guides(fill = "none", color = "none") +
  theme_bw(base_size = 12) +
  #theme(legend.position = "none")
  theme(legend.position = "bottom", text = element_text(size = 10))

sd_chick

(mean_nest + mean_chick)/(sd_nest + sd_chick) +
  plot_annotation(tag_levels = "A")


# mod2 as across pair instead of across year, for comparison 
mod2_pair<- brm(bf(logIVI ~ 1 + cschicksl + snestlingagel +  
                (1 + snestlingagel |p|fpair) + (1 | fsite), 
              sigma ~ 1 + cschicksl+ snestlingagel+ (1|p|fpair)), 
           data = data1, 
           warmup = 1000, 
           iter = 5000, 
           chains = 2,
           cores  = 2,
           control = list(adapt_delta = 0.99, max_treedepth = 15),
           backend = "cmdstanr")


summary(mod2_pair)
ranef(mod2_pair)
fixef(mod2_pair)


saveRDS(mod2, file = "Rebekah_Kim/mod2_pair.rds")

  
  #fixed effects only#

m1a <- brm(bf(logIVI ~ 1+ cschicksl + snestlingagel,
           sigma ~ 1 + cschicksl+ snestlingagel+ (1|p|fyear)), 
           data = data1, 
           warmup = 1000, 
           iter = 5000, 
           chains = 3,
           cores  = 2,
           control = list(adapt_delta = 0.99, max_treedepth = 15),
           backend = "cmdstanr")

summary(m1a)
fixef(m1a)

  #fixed effects plus random for site#
  
   
  
  
m1b <- brm(bf(logIVI ~ 1+ cschicksl + snestlingagel + (1 | fsite),
              sigma ~ 1 + cschicksl+ snestlingagel+ (1|p|fyear)), 
           data = data1, 
           warmup = 1000, 
           iter = 5000, 
           chains = 3,
           cores  = 2,
           control = list(adapt_delta = 0.99, max_treedepth = 15),
           backend = "cmdstanr")

summary(m1b)
ranef(m1b)
fixef(m1b)

  #fixed effects plus random for pair#
  
  
  
  
m1c <- brm(bf(logIVI ~ 1+ cschicksl + snestlingagel + (1|fpair),
              sigma ~ 1 + cschicksl+ snestlingagel+ (1|p|fyear)), 
           data = data1, 
           warmup = 1000, 
           iter = 5000, 
           chains = 3,
           cores  = 2,
           control = list(adapt_delta = 0.99, max_treedepth = 15),
           backend = "cmdstanr")

summary(m1c)
ranef(m1c)
fixef(m1c)

  #fixed effects plus random for site and pair#
  
  
  
  
m1d <- brm(bf(logIVI ~ 1+ cschicksl + snestlingagel + (1 | fsite) + (1|fpair),
              sigma ~ 1 + cschicksl+ snestlingagel+ (1|p|fyear)), 
           data = data1, 
           warmup = 1000, 
           iter = 5000, 
           chains = 3,
           cores  = 2,
           control = list(adapt_delta = 0.99, max_treedepth = 15),
           backend = "cmdstanr")

summary(m1d)
ranef(m1d)
fixef(m1d)

  #fixed effects, plus random for site and pair and random intercept for year#
  
  
  
  
m1e <- brm(bf(logIVI ~ 1+ cschicksl + snestlingagel + (1|fyear) + (1 | fsite) + (1|fpair),
              sigma ~ 1 + cschicksl+ snestlingagel+ (1|p|fyear)), 
           data = data1, 
           warmup = 1000, 
           iter = 5000, 
           chains = 3,
           cores  = 2,
           control = list(adapt_delta = 0.99, max_treedepth = 15),
           backend = "cmdstanr")

summary(m1e)
ranef(m1e)
fixef(m1e)

  #fixed effects, plus random for site and pair and random slope for nestling age nested within year#
  
  
  
  
m1f <- brm(bf(logIVI ~ 1+ cschicksl + snestlingagel + (1+ snestlingagel|fyear) 
              + (1 | fsite) + (1|fpair),
              sigma ~ 1 + cschicksl+ snestlingagel+ (1|p|fyear)), 
           data = data1, 
           warmup = 1000, 
           iter = 5000, 
           chains = 3,
           cores  = 2,
           control = list(adapt_delta = 0.99, max_treedepth = 15),
           backend = "cmdstanr")

summary(m1f)
ranef(m1f)
fixef(m1f)

  
#####13. Model comparisons 

  #loo_compare#

  
loo1 <- loo(m1a)
loo2 <- loo(m1b)
loo3 <- loo(m1c)
loo4 <- loo(m1d)
loo5 <- loo(m1e)
loo6 <- loo(m1f)
loo7 <- loo(m1g)
loo8 <- loo(mod2)
loo9 <- loo(mod3)
  
  
loo_compare(loo1, loo2, loo3, loo4, loo5, loo6, loo7, loo8, loo9)

##### covariance plots 

covariance_data <- read.csv("G:/.shortcut-targets-by-id/15aIOTzK-SdA0QZzPxWaQk_8cNO0OoEUl/Rebekah thesis/ACROSS YEARS PAPER/Writing Data Chapter/DRAFTS/2023/Covariance_plots_new.csv")
names(covariance_data)
# Create the plots

intercept_slope <- ggplot(covariance_data, aes(x=age_slope, y=intercept, color=as.factor(year), fill=as.factor(year))) + 
  geom_point(size=3, shape=21) +
  geom_errorbarh(aes(xmin=age_lower, xmax=age_upper, color=as.factor(year)), height=0, size=0.5) +
  geom_errorbar(aes(ymin=in_lower, ymax=in_upper, color=as.factor(year)), width=0, size=0.5) +
  labs(x="Nestling Age", y="Intercept", title="A", color="Year", fill="Year") +
  theme(axis.text = element_text(size=12), 
        axis.title = element_text(size=16), 
        legend.title = element_text(size=16))
print(intercept_slope)

intercept_variance <- ggplot(covariance_data, aes(x=intercept, y=variance, color=as.factor(year), fill=as.factor(year))) + 
  geom_point(size=3, shape=21) +
  geom_errorbarh(aes(xmin=in_lower, xmax=in_upper, color=as.factor(year)), height=0, size=0.5) +
  geom_errorbar(aes(ymin=var_lower, ymax=var_upper, color=as.factor(year)), width=0, size=0.5) +
  labs(x="Intercept", y="Variance", title="B", color="Year", fill="Year") +
  theme(axis.text = element_text(size=12), 
        axis.title = element_text(size=16), 
        legend.title = element_text(size=16))
print(intercept_variance)

slope_variance <- ggplot(covariance_data, aes(x=age_slope, y=variance, color=as.factor(year), fill=as.factor(year))) + 
  geom_point(size=3, shape=21) +
  geom_errorbarh(aes(xmin=age_lower, xmax=age_upper, color=as.factor(year)), height=0, size=0.5) +
  geom_errorbar(aes(ymin=var_lower, ymax=var_upper, color=as.factor(year)), width=0, size=0.5) +
  labs(x="Nestling age", y="Variance", title="C", color="Year", fill="Year") +
  theme(axis.text = element_text(size=12), 
        axis.title = element_text(size=16), 
        legend.title = element_text(size=16))
print(slope_variance)